#include <iostream>
#include <stdio.h>
#include <signal.h>
#include <openssl/md5.h>

#include <ftc/DefaultDataProvider.h>
#include <ftc/FileServerConfig.h>
#include <ftc/FileServer.h>
#include <ftc/AccessKey.h>
#include <ftc/Log.h>
#include <ftc/ErrnoException.h>
#include <ftc/DefaultServerExceptionHandler.h>

#include "FileSystemUtils.h"

using namespace tecgraf::ftc::v1_04_01;

const std::size_t max_chunk_size = 1024u*1024u*500u; // 500 MB
const std::size_t default_chunk_size = 1024u*1024u; // 1 MB

static FileServer * pServer = NULL;

void stop_server(int sig) {
 if(pServer != NULL)
 {
     FTC_LOG_INFO(" Stoping FTC server " << std::endl);
     pServer->stop();
     (void) signal(SIGINT, SIG_DFL);
 }
}

int main(int argc, char **argv)
{
    (void) signal ( SIGINT , stop_server );
    unsigned short port = 25555;
    std::string hostname = "localhost", dirname;
    size_t chunk_size = default_chunk_size; // 1MB
    int opt;

    while ((opt = getopt(argc, argv, "h:p:c:")) != -1)
    {
      switch (opt)
      {
      case 'h':
        hostname = optarg;
        break;
      case 'p':
        port  = (unsigned short) ::atoi(optarg);
        break;
      case 'c':
        chunk_size = ::atol(optarg);
        if(errno != 0) 
          chunk_size = default_chunk_size;
        else
          chunk_size = chunk_size > max_chunk_size ? max_chunk_size : chunk_size;
        break;
      default: /* ’?’ */
        std::cerr <<  "Usage: " << argv[0]
                  << " [-h hostname] [-p port] [-c chunk_size] /dir/path " << std::endl;
        return EXIT_FAILURE;
      }
    }

    if (optind >= argc)
    {
      std::cout << "O nome do arquivo deve ser fornecido." <<std::endl;
      return EXIT_FAILURE;
    }

    dirname = argv[optind];

    DefaultDataProvider dataProvider;
    FileServerConfig config;
    config.max_clients(1000);
    config.is_test_mode(true);
    config.port(port);
    config.hostname(hostname);
    config.chunk_size(chunk_size);
    config.output_log_filename("./ftc_debug.log");
    config.log_level(tecgraf::ftc::v1_04_01::ServerConfig::LOG_DEBUG);
    tecgraf::ftc::v1_04_01::ftcLog.enable(config);

    FileServer server(dataProvider,config);
    pServer = &server;

    DefaultServerExceptionHandler exceptionHandler;
    server.setExceptionHandler(&exceptionHandler);
    
    std::vector<std::string> files;

    getDirList(dirname,files);
    size_t size = files.size();
    std::string file; 
    unsigned char keystr[MD5_DIGEST_LENGTH];
    for(unsigned int i = 0; i < size ; i++ )
    {
        file = files[i];
        if( ! isDir(file) )
        {
            MD5((const unsigned char*)file.c_str(), file.size(), keystr );
            AccessKey key( keystr , MD5_DIGEST_LENGTH , false );
            server.createDataChannelInfo( NULL , file , &key );
            std::cout << "Serving: " << file << std::endl;
        }
    }

    try {
        server.dispatch();
    }
    catch(ErrnoException & e){
        std::cout << "FTC Server Exception: " << e.what() << std::endl;
        std::cout << "Message: " << e.message() << std::endl;
    }


    return 0;
}
