
-------------------------------------------------------------------------------
---- FTC RECORDS --------------------------------------------------------------
-------------------------------------------------------------------------------
--  [record] = {
--           [1] = "3145728000";           // File Size
--           [2] = "143.483";              // Transfer time
--           [3] = "21410.201905452213";   // Transfer rate (KB/s)
--           [4] = "1048576";              // Buffer Size used
--         };
-------------------------------------------------------------------------------

local function addRecord(result,record)
	local size = record[1]
	if not result[size] then
		result[size]={ }
	end

	local t = result[size]	

	local buffersize = record[4] or 1 -- For files without buffer size 
	
	if not t[buffersize] then
		t[buffersize] = { }
	end

    table.insert(t[buffersize], { duration = record[2] , speed = record[3] })
end


local function getFileRecords(filename)
	local file = io.open(filename,"r")

	if not file then
		print("Erro ao abrir o arquivo: ".. filename)
		os.exit(1)
	end

	local result = {}
	for line in file:lines() do
		local t = fromCSV(line)
		if t then 
			addRecord(result,t)
		else
			break
		end
	end
	
	file:close()

	return result
end

-- Calculate average
local function calculateAverage(result)
	for size,bufferTable in pairs(result) do
		for bufferSize,records in pairs(bufferTable) do
			local speed =0
			local duration =0
			local nrecords = #records
			
			for i=1,nrecords do
				speed = speed + records[i].speed
				duration = duration + records[i].duration
			end
			bufferTable[bufferSize] = {
										speed = speed/nrecords,
										duration = duration/nrecords
								      }
		end
	end
end


function processFtc(descritor)
	local file = io.open( descritor.output ,"w")

	if not file then
		print("Erro ao abrir o arquivo: " .. descritor.output)
		os.exit(1)
	end

	for i=1,#descritor.files do
		local implementation = descritor.files[i].name
		local filename = descritor.files[i].filename

		local result = getFileRecords(filename)
		
		calculateAverage(result)
		
		file:write("#".. implementation .. "\n")
		--print("#".. implementation )
		for size,bufferTable in orderedPairs(result) do
			for bufferSize,records in orderedPairs(bufferTable) do
				local record = bufferTable[bufferSize]  
				file:write(size .. "   " .. bufferSize  .. "   " .. record.duration .. "   " .. record.speed .. "\n")
				--print(size .. "   " .. bufferSize  .. "   " .. record.duration .. "   " .. record.speed )
			end
		end
		file:write("\n\n\n")

	end

	file:close()
end 

