
-------------------------------------------------------------------------------
---- IPERF RECORDS ------------------------------------------------------------
-------------------------------------------------------------------------------
--  [record] = {
--           [1]  = 20081213012915,  // Date
--           [2]  = 10.0.16.14,      // Client address
--           [3]  = 40289,           // Client port
--           [4]  = 10.0.16.6,       // Server address
--           [5]  = 5001,            // Server Port
--           [6]  = 3,               // Unknown
--           [7]  = 0.0-20.1,        // Duration
--           [8]  = 238624768,       // Data transfered
--           [9]  = 95135370,        // Bits/Sec
--           [10] = 2510,            // Window Size
--         };
-------------------------------------------------------------------------------

local function getIperfFileRecords(filename)
	local file = io.open(filename,"r")

	if not file then
		print("Erro ao abrir o arquivo: ".. filename)
		os.exit(1)
	end

	local result = {}
	for line in file:lines() do
		local t = fromCSV(line)
		local windowSize = t[10]
		if not result[windowSize] then
			result[windowSize]={}
		end
		table.insert(result[windowSize],t[9])
	end
	
	file:close()

	return result
end

-- Calculate average
local function calculateIperfAverage(result)
	for windowSize,values in pairs(result) do
		local nrecords = #values
		local average = 0
		for _,value in pairs(values) do
			average = average + value
		end
		average = average /( nrecords * 8 * 1024)
		result[windowSize] = average
	end
end

function processIperf(descritor)
	local file = io.open( descritor.output ,"w")

	if not file then
		print("Erro ao abrir o arquivo: " .. descritor.output)
		os.exit(1)
	end

	for i=1,#descritor.files do
		local implementation = descritor.files[i].name
		local filename = descritor.files[i].filename

		local result = getIperfFileRecords(filename)
		
		calculateIperfAverage(result)
		
		file:write("#".. implementation .. "\n")
		--print("#".. implementation )
		for windowSize,speed in pairs(result) do
			file:write( windowSize  .. "   " .. speed .. "\n")
		end
		file:write("\n\n\n")

	end

	file:close()
end 
