package ftc.server.v1_3;

import java.util.logging.Level;

import tecgraf.ftc_1_3.server.FileServerConfig;
import ftc.ServerConfig;

class FtcServerConfig implements FileServerConfig {

  private ServerConfig config;

  public FtcServerConfig(ServerConfig config) {
    this.config = config;
  }

  /**
   * Retorna O nome do host para o servidor de arquivos.
   * 
   * @return hostName
   */
  @Override
  public String getHostName() {
    return config.getHostName();
  }

  /**
   * @param hostName O nome do host para o servidor de arquivos.
   */
  @Override
  public void setHostName(String hostname) {
    config.setHostName(hostname);
  }

  /**
   * Retorna a porta para o servidor de arquivos.
   * 
   * @return port A porta para o servidor de arquivos.
   */
  @Override
  public int getPort() {
    return config.getPort();
  }

  /**
   * @param port A porta para o servidor de arquivos. Caso seja {@literal 0},
   *        uma porta disponvel ser obtida.
   */
  @Override
  public void setPort(int port) {
    config.setPort(port);
  }

  /**
   * Retorna Tempo maximo de espera do metodo select em milisegundos.
   * 
   * @return selectTimeout
   */
  @Override
  public long getSelectTimeout() {
    return config.getSelectTimeout();
  }

  /**
   * @param selectTimeout Tempo maximo de espera do metodo select em
   *        milisegundos.
   */
  @Override
  public void setSelectTimeout(long selectTimeout) {
    config.setSelectTimeout(selectTimeout);
    ;
  }

  /**
   * Retorna
   * 
   * @return clientTimeout
   */
  @Override
  public long getClientTimeout() {
    return config.getClientTimeout();
  }

  /**
   * @param clientTimeout
   */
  @Override
  public void setClientTimeout(long clientTimeout) {
    config.setClientTimeout(clientTimeout);
  }

  /**
   * Retorna O numero maximo de clientes
   * 
   * @return maxClients
   */
  @Override
  public int getMaxClients() {
    return config.getMaxClients();
  }

  /**
   * @param maxClients O numero maximo de clientes
   */
  @Override
  public void setMaxClients(int maxClients) {
    config.setMaxClients(maxClients);
  }

  /**
   * Retorna Tamanho do espao de memoria utilizado na comunicaao com cada
   * cliente.
   * 
   * @return clientBufferSize
   */
  @Override
  public int getClientBufferSize() {
    return config.getClientBufferSize();
  }

  /**
   * @param clientBufferSize Define o tamanho do espao de memoria utilizado na
   *        comunicaao com cada cliente.
   */
  @Override
  public void setClientBufferSize(int clientBufferSize) {
    config.setClientBufferSize(clientBufferSize);
  }

  /**
   * Retora o valor da politica de aceitao de novos clientes. True para
   * aceitar o numero maximo de clientes e false para aceitar um cliente por
   * vez.
   * 
   * @return boolean
   */
  @Override
  public boolean acceptMaxPossible() {
    return config.acceptMaxPossible();
  }

  /**
   * Define a politica de aceitao de novos clientes. True para aceitar o
   * numero maximo de clientes e false para aceitar um cliente por vez.
   * 
   * @param value
   */
  @Override
  public void setAcceptMaxPossible(boolean value) {
    config.setAcceptMaxPossible(value);
  }

  /**
   * Retorna True se o servidor deve executar em modo de teste.
   * 
   * @return testMode
   */
  @Override
  public boolean isTestMode() {
    return config.isTestMode();
  }

  /**
   * Define se o servidor deve executar em modo de teste.
   * 
   * @param testMode
   */
  @Override
  public void setTestMode(boolean testMode) {
    config.setTestMode(testMode);
  }

  /**
   * @param serverRoot
   */
  public void setServerRoot(String serverRoot) {
    config.setServerRoot(serverRoot);
  }

  /**
   * Retorna
   * 
   * @return serverRoot
   */
  public String getServerRoot() {
    return config.getServerRoot();
  }

  /**
   * Define o nome do arquivo de saida do log.
   * 
   * @param filename
   */
  @Override
  public void setOutputLogFilename(String filename) {
    config.setOutputLogFilename(filename);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public String getOutputLogFilename() {
    return config.getOutputLogFilename();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public long getChannelRequestTimeout() {
    return config.getChannelRequestTimeout();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void setChannelRequestTimeout(long value) {
    config.setChannelRequestTimeout(value);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public int getMaxChannelRequests() {
    return config.getMaxChannelRequests();
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void setMaxChannelRequests(int maxChannelRequests) {
    config.setMaxChannelRequests(maxChannelRequests);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public void setLoglevel(Level loglevel) {
    config.setLoglevel(loglevel);
  }

  /**
   * {@inheritDoc}
   */
  @Override
  public Level getLoglevel() {
    return config.getLoglevel();
  }

}
