
local io = io
local print = print
local ipairs = ipairs
local pairs = pairs
local setmetatable = setmetatable 
local os = os
local ftcbench = ftcbench 

module("ftcbench.javaserver")

local name = "FTC Java Server"

local profcmd = ' -agentlib:hprof=cpu=times -classpath "./java/lib/ftcbench.jar:./java/lib/ftc-1.4.0.1.jar:./java/lib/ftc-1.3.1.jar:./java/lib/ftc-1.2.0.jar:./java/lib/ftc-1.1.5.jar" ftc.FtcServer -ftcversion FTC_V1_4_0'
local command = ' -XX:MaxDirectMemorySize=256M -classpath "./java/lib/ftcbench.jar:./java/lib/ftc-1.4.0.1.jar:./java/lib/ftc-1.3.1.jar:./java/lib/ftc-1.2.0.jar:./java/lib/ftc-1.1.5.jar:./java/lib/args4j-2.0.9.jar" ftc.FtcServer -ftcversion FTC_V1_4_0'

local conf 

function setConfig(config)
    conf = config
end

function getName()
    return name
end

--[[
Usage: ./runJavaServer [-h host] [-p port] -f /dir/path/ 
 -a     : Define se o servidor deve tentar aceitar o numero maximo de clientes.
 -b N   : Tamanho do buffer para cada cliente.
 -f VAL : Pasta com os arquivos a serem tranferidos.
 -h VAL : Nome/IP do servidor FTC.
 -m N   : Numero maximo de clientes.
 -p N   : Porta TCP do servidor FTC.
 -t N   : Tempo em milisegundos de espera por conexao inativa
 -x N   : Timeout do metodo 'select'.
]]

local options = {
    SERVER_FILES_DIR          = { key = ' -f ', hasValue=true  },
    SERVER_AGRESSIVE_ACCEPT   = { key = ' -a ', hasValue=false },
    SERVER_ADDRESS            = { key = ' -h ', hasValue=true  },
    SERVER_PORT               = { key = ' -p ', hasValue=true  },
    SERVER_MAX_CLIENTS        = { key = ' -m ', hasValue=true  },
    SERVER_CONNECTION_TIMEOUT = { key = ' -t ', hasValue=true  },
    SERVER_SELECT_TIMEOUT     = { key = ' -x ', hasValue=true  },
    BufferSize                = { key = ' -b ', hasValue=true  },
}

local function getopts()
    local params = ftcbench.parameters 
    local opts = ' '
    
    for optName,t in pairs(options) do 
        if params[optName] ~= nil then
            opts = opts .. t.key
            if t.hasValue then
                opts = opts .. params[optName]
            end
        elseif conf[optName] then
            opts = opts .. t.key
            if t.hasValue then
                opts = opts .. conf[optName]
            end
        end
    end

    return opts
end

function run()
    local cmd = command
    if conf.Profilling then
        cmd = profcmd
    end
    
    local fullcmd = ftcbench.parameters.JAVA_BIN .. cmd .. getopts() 
    
    if conf.Debug then print(fullcmd) end

    os.execute( fullcmd  )
end

